package com.hc.business.service;

import com.hc.business.dto.CourseVideoDto;
import com.hc.business.model.Course;
import com.hc.business.model.CourseChapterVideo;
import org.springframework.stereotype.Component;
import com.github.pagehelper.PageInfo;

import java.util.List;


/**
 * 课程表(Course)表服务接口
 *
 * @author java
 * @since 2020-11-09 10:04:45
 */

@Component
public interface CourseService {

    /**
     * 通过ID查询单条数据
     *
     * @param courseId 主键
     * @return 实例对象
     */
    Course queryById(Integer courseId);

    /**
     * 新增数据
     *
     * @param course 实例对象
     * @return 实例对象
     */
    Course insert(Course course);

    /**
     * 修改数据
     *
     * @param course 实例对象
     * @return 实例对象
     */
    Course update(Course course);

    /**
     * 通过主键删除数据
     *
     * @param courseId 主键
     * @return 是否成功
     */
    boolean deleteById(Integer courseId);

    /**
     * 依据老师名称获取课程
     *
     * @param name 老师名称
     * @return 实例对象数组
     */
    List<Course> queryTeacherName(String name);

    /**
     * 依据课程名称获取课程
     *
     * @param name 课程名称
     * @return 实例对象数组
     */
    List<Course> queryCourseName(String name);

    /**
     * 分页查询多条数据
     *
     * @param page  页码
     * @param size  查询条数
     * @param valid
     * @return 对象列表
     */
    PageInfo queryAllByLimit(int page, int size, Integer valid);

    /**
     * 分页根据类型查询课程
     *
     * @param page   页码
     * @param size   查询条数
     * @param typeId 对象列表
     * @return 实例对象
     */
    PageInfo queryAllByLimitAndTypeId(int page, int size, Integer typeId);

    /**
     * 查找課程的所有章節  拼接课程视频 和 播放记录
     *
     * @param courseId
     * @param userId
     * @return
     */
    List<CourseVideoDto> getCourseChapterAndVideoPosition(Integer courseId, Integer userId, Integer classId);


    /**
     * 查找課程的所有视频
     *
     * @param courseId
     * @return
     * @return
     */
    List<CourseChapterVideo> getAllVideos(Integer courseId);


}