package com.hc.business.service;

import com.github.pagehelper.PageInfo;
import com.hc.business.model.News;
import org.springframework.stereotype.Component;


/**
 * 新闻表
 * (News)表服务接口
 *
 * @author java
 * @since 2020-11-20 11:48:37
 */

@Component
public interface NewsService {

    /**
     * 通过ID查询单条数据
     *
     * @param newsId 主键
     * @return 实例对象
     */
    News queryById(Integer newsId);

    /**
     * 新增数据
     *
     * @param news 实例对象
     * @return 实例对象
     */
    News insert(News news);

    /**
     * 修改数据
     *
     * @param news 实例对象
     * @return 实例对象
     */
    News update(News news);

    /**
     * 通过主键删除数据
     *
     * @param newsId 主键
     * @return 是否成功
     */
    boolean deleteById(Integer newsId);

    /**
     * 依据标签id查询 news
     *
     * @param tagId 标签id
     * @return 实例对象数组
     */
    PageInfo queryListByTagId(Integer tagId, int page, int size);

    /**
     * 分页查询多条数据
     *
     * @param page 页码
     * @param size 查询条数
     * @return 对象列表
     */
    PageInfo queryAllByLimit(int page, int size);


}