package com.hc.web.controller.browser.back;

import com.hc.business.model.CourseChapterVideo;
import com.hc.business.service.CourseChapterVideoService;
import com.hc.core.utils.result.Result;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;


/**
 * 课程视频(CourseChapterVideo)表控制层
 *
 * @author java
 * @since 2020-11-09 10:04:56
 */

@RestController
@RequestMapping("/new/api/courseChapterVideo")
public class CourseChapterVideoController {

    /**
     * 服务对象
     */
    private final CourseChapterVideoService courseChapterVideoService;

    public CourseChapterVideoController(CourseChapterVideoService courseChapterVideoService) {
        this.courseChapterVideoService = courseChapterVideoService;
    }

    @GetMapping("/{id}")
    @ApiOperation(value = "依据主键获取 CourseChapterVideo", response = Result.class)
    public Result selectDetail(@PathVariable("id") Integer id) {
        return Result.success(this.courseChapterVideoService.queryById(id));
    }

    @PostMapping("/insert")
    @ApiOperation(value = "新增 CourseChapterVideo", response = Result.class)
    public Result addCourseChapterVideo(@Valid @RequestBody CourseChapterVideo courseChapterVideo) {
        return Result.success(courseChapterVideoService.insert(courseChapterVideo));
    }

    @PutMapping("/update")
    @ApiOperation(value = "修改 CourseChapterVideo", response = Result.class)
    public Result updateCourseChapterVideo(@RequestBody CourseChapterVideo courseChapterVideo) {
        return Result.success(courseChapterVideoService.update(courseChapterVideo));
    }

    @DeleteMapping("/delete/{id}")
    @ApiOperation(value = "依据主键删除 CourseChapterVideo", response = Result.class)
    public Result deleteCourseChapterVideo(@PathVariable("id") Integer id) {
        return Result.success(courseChapterVideoService.deleteById(id));
    }

    @GetMapping("/list")
    @ApiOperation(value = "获取 CourseChapterVideo列表(分页)", response = Result.class)
    public Result listCourseChapterVideo(@RequestParam(defaultValue = "0") Integer page,
                                         @RequestParam(defaultValue = "0") Integer size) {
        return Result.success(courseChapterVideoService.queryAllByLimit(page, size));
    }


}