package com.hc.gpweb.handler;


import com.hc.gpcore.enums.InfoEnum;
import com.hc.gpcore.exception.ResponseException;
import com.hc.gpcore.exception.UserAuthorizeException;
import com.hc.gpcore.utils.result.Result;
import org.springframework.http.HttpStatus;
import org.springframework.jdbc.UncategorizedSQLException;
import org.springframework.validation.BindingResult;
import org.springframework.validation.FieldError;
import org.springframework.web.bind.MethodArgumentNotValidException;
import org.springframework.web.bind.MissingServletRequestParameterException;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.bind.annotation.RestControllerAdvice;

import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.util.Set;

/**
 * @author JIA
 */

@RestControllerAdvice
public class ExceptionResultHandler {


    @ExceptionHandler(MethodArgumentNotValidException.class)
    @ResponseStatus(HttpStatus.OK)
    @ResponseBody
    public Result handleMethodArgumentNotValidException(MethodArgumentNotValidException exception) {
        StringBuilder errorInfo = new StringBuilder();
        BindingResult bindingResult = exception.getBindingResult();
        for (int i = 0; i < bindingResult.getFieldErrors().size(); i++) {
            if (i > 0) {
                errorInfo.append(",");
            }
            FieldError fieldError = bindingResult.getFieldErrors().get(i);
            errorInfo.append(fieldError.getField()).append(" :").append(fieldError.getDefaultMessage());
        }

        //返回BaseResponse
        Result response = new Result();
        response.setMsg(errorInfo.toString());
        response.setCode(401);
        return response;
    }

    @ExceptionHandler(MissingServletRequestParameterException.class)
    @ResponseStatus(HttpStatus.BAD_REQUEST)
    public Result handleRequestParameterException(MissingServletRequestParameterException e) {
        return Result.exception(HttpStatus.BAD_REQUEST.value(), e.getMessage());
    }

    @ExceptionHandler(ConstraintViolationException.class)
    @ResponseStatus(HttpStatus.BAD_REQUEST)
    @ResponseBody
    public Result handleConstraintViolationException(ConstraintViolationException exception) {
        StringBuilder errorInfo = new StringBuilder();
        String errorMessage;

        Set<ConstraintViolation<?>> violations = exception.getConstraintViolations();
        for (ConstraintViolation<?> item : violations) {
            errorInfo.append(item.getMessage()).append(",");
        }
        errorMessage = errorInfo.toString().substring(0, errorInfo.toString().length() - 1);

        //返回BaseResponse
        Result response = new Result();
        response.setMsg(errorMessage);
        response.setCode(402);
        return response;
    }


    @ExceptionHandler(ResponseException.class)
    @ResponseStatus(HttpStatus.OK)
    @ResponseBody
    public Result handleResponseException(ResponseException e) {
        return Result.exception(e.getCode(), e.getMessage());
    }

    @ExceptionHandler(UncategorizedSQLException.class)
    @ResponseBody
    @ResponseStatus(HttpStatus.NOT_FOUND)
    public Result handleSqlException(UncategorizedSQLException e) {
        return Result.exception(e.hashCode(), e.getCause().toString());
    }

    @ExceptionHandler(NullPointerException.class)
    @ResponseBody
    @ResponseStatus(HttpStatus.BAD_REQUEST)
    public Result handleNullPointerException(NullPointerException e) {
        return Result.exception(HttpStatus.BAD_REQUEST.value(), e.getMessage());
    }

    @ExceptionHandler(UserAuthorizeException.class)
    @ResponseBody
    @ResponseStatus(HttpStatus.NON_AUTHORITATIVE_INFORMATION)
    public Result handlerAuthorizeException() {
        return Result.exception(InfoEnum.TOKEN_EXPIRED.getKey(), InfoEnum.TOKEN_EXPIRED.getMsg());
    }

    @ExceptionHandler(Exception.class)
    @ResponseBody
    @ResponseStatus(HttpStatus.BAD_REQUEST)
    public Result handleException(Exception e) {
        return Result.exception(-1, e.getMessage());
    }

}
