package com.hc.business.service;

import com.github.pagehelper.PageInfo;
import com.hc.business.model.ZccmClassConfig;
import org.springframework.stereotype.Component;

import java.util.List;


/**
 * 班次表(ZccmClassConfig)表服务接口
 *
 * @author java
 * @since 2020-11-19 16:12:31
 */

@Component
public interface ZccmClassConfigService {

    /**
     * 通过ID查询单条数据
     *
     * @param classConfigId 主键
     * @return 实例对象
     */
    ZccmClassConfig queryById(Integer classConfigId);

    /**
     * 新增数据
     *
     * @param classConfig 实例对象
     * @return 实例对象
     */
    ZccmClassConfig insert(ZccmClassConfig classConfig);

    /**
     * 修改数据
     *
     * @param classConfig 实例对象
     * @return 实例对象
     */
    ZccmClassConfig update(ZccmClassConfig classConfig);

    /**
     * 通过主键删除数据
     *
     * @param classConfigId 主键
     * @return 是否成功
     */
    boolean deleteById(Integer classConfigId);

    /**
     * 分页查询多条数据
     *
     * @param page 页码
     * @param size 查询条数
     * @return 对象列表
     */
    PageInfo queryAllByLimit(int page, int size);

    /**
     * 校验查询培训班
     *
     * @param valid 是否上线
     * @param page  页码
     * @param size  查询条数
     * @return 实例对象数组
     */
    PageInfo queryByValid(Integer valid, int page, int size);

    /**
     * 培训班名称查询培训班
     *
     * @param name 培训班名称
     * @return 实例对象数组
     */
    List<ZccmClassConfig> queryByClassName(String name);

    /**
     * 地区id查询培训班
     *
     * @param areaId 地区id
     * @param page   页码
     * @param size   查询条数
     * @return 对象列表
     */
    PageInfo queryByAreaId(Integer areaId, int page, int size);


    /**
     * 学习时间查询培训班
     *
     * @param studyStartTime 学习开始时间
     * @param page           页码
     * @param size           查询条数
     * @return 对象列表
     */
    PageInfo queryByTime(Long studyStartTime, Integer page, Integer size);
}