package com.hc.business.service;

import com.github.pagehelper.PageInfo;
import com.hc.business.dto.ZccmPaperCommitDTO;
import com.hc.business.dto.ZccmPaperResultDto;
import com.hc.business.model.ZccmPaper;
import com.hc.core.utils.result.Result;
import org.springframework.stereotype.Component;


/**
 * 试卷表(ZccmPaper)表服务接口
 *
 * @author java
 * @since 2020-12-07 11:34:36
 */

@Component
public interface ZccmPaperService {

    /**
     * 通过ID查询单条数据
     *
     * @param paperId 主键
     * @return 实例对象
     */
    ZccmPaper queryById(Integer paperId);

    /**
     * 新增数据
     *
     * @param paper 实例对象
     * @return 实例对象
     */
    ZccmPaper insert(ZccmPaper paper);

    /**
     * 修改数据
     *
     * @param paper 实例对象
     * @return 实例对象
     */
    ZccmPaper update(ZccmPaper paper);

    /**
     * 通过主键删除数据
     *
     * @param paperId 主键
     * @return 是否成功
     */
    boolean deleteById(Integer paperId);

    /**
     * 分页查询多条数据
     *
     * @param page 页码
     * @param size 查询条数
     * @return 对象列表
     */
    PageInfo queryAllByLimit(int page, int size);


    /**
     * 获取试卷下的习题
     *
     * @param paperId 试卷id
     * @return 实例对象
     */
    ZccmPaperResultDto queryQuestionList(Integer paperId);

    /**
     * 提交试卷返回成绩
     *
     * @param commitDTO 提交
     * @return 实例对象
     */
    Result paperCommit(ZccmPaperCommitDTO commitDTO);
}