package com.hc.business.service;

import com.hc.business.dto.*;
import com.hc.business.model.ZccmUser;
import com.hc.business.model.login.AccessEntity;
import com.hc.business.model.login.AuthEntity;
import org.springframework.stereotype.Component;
import com.github.pagehelper.PageInfo;

import java.util.List;


/**
 * 用户表(ZccmUser)表服务接口
 *
 * @author java
 * @since 2020-11-09 10:04:14
 */

@Component
public interface ZccmUserService {

    /**
     * 通过ID查询单条数据
     *
     * @param userId 主键
     * @return 实例对象
     */
    ZccmUser queryById(Integer userId);

    /**
     * 新增数据
     *
     * @param user 实例对象
     * @return 实例对象
     */
    ZccmUser insert(ZccmUser user);

    /**
     * 修改数据
     *
     * @param user 实例对象
     * @return 实例对象
     */
    ZccmUser update(ZccmUser user);

    /**
     * 通过主键删除数据
     *
     * @param userId 主键
     * @return 是否成功
     */
    boolean deleteById(Integer userId);

    /**
     * 分页查询多条数据
     *
     * @param page 页码
     * @param size 查询条数
     * @return 对象列表
     */
    PageInfo queryAllByLimit(int page, int size);

    /**
     * 用户登录（账号，密码）
     *
     * @param authEntity 实例对象
     * @return 实例对象
     */
    AccessEntity userLogin(AuthEntity authEntity);


    /**
     * 用户登录（手机号登录）
     *
     * @param zccmSmsLoginDto 实例对象
     * @return 实例对象
     */
    AccessEntity userLoginSms(ZccmSmsLoginDto zccmSmsLoginDto);

    /**
     * 用户注册
     *
     * @param zccmRetrievePasswordDto 实例对象
     * @return 实例对象
     */
    AccessEntity userRegister(ZccmRetrievePasswordDto zccmRetrievePasswordDto);

    /**
     * 发送授权码
     *
     * @param phone 实例对象
     * @return 实例对象
     */
    String sendAuthCode(String phone);

    /**
     * 校验验证码-找回密码
     *
     * @param zccmRetrievePasswordDto 实例对象
     * @return 实例对象
     */
    ZccmUser retrievePassword(ZccmRetrievePasswordDto zccmRetrievePasswordDto);

    /**
     * 依据用户手机号查询用户
     *
     * @param userMobile 手机号
     * @return 实例对象数组
     */
    List<ZccmUser> queryByMobile(String userMobile);

    /**
     * 身份证查询用户
     *
     * @param cardId 身份证号
     * @return 实例对象数组
     */
    List<ZccmUser> queryUserByCard(String cardId);


    /**
     * 姓名查询用户
     *
     * @param name 身份证号
     * @return 实例对象数组
     */
    List<ZccmUser> queryUserByName(String name);


    /**
     * 姓名查询用户
     *
     * @param name 身份证号
     * @return 实例对象数组
     */
    List<ZccmUserListDto> queryUserByClassName(String name, int pay);

    /**
     * 获取用户统计数量
     *
     * @return 实例对象
     */
    ZccmUserTimeTotal queryUserCount();

    /**
     * 获取最近七天用户统计数量
     *
     * @return 实例对象数组
     */
    List<ZccmStaTimeTable> queryByUserCount();


}